S3_BUCKET_URI = "s3://fast-datasets/{ds}"

# Read Only Access
AWS_ACCESS_KEY_ID = "AKIAVXFFSLWHED2I7WGB"
AWS_SECRET_ACCESS_KEY = "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"

# Download Temp Path
TMP_PATH = "/tmp/{ds}"

# Divide String
D_S = "=" * 50
